Module: Google::Iam::Credentials

Defined in:
lib/google/iam/credentials.rb,
lib/google/iam/credentials/version.rb

Constant Summary collapse

VERSION =
"1.7.0"

Class Method Summary collapse

Class Method Details

.iam_credentials(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for IAMCredentials.

By default, this returns an instance of Google::Iam::Credentials::V1::IAMCredentials::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the IAMCredentials service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the IAMCredentials service. You can determine whether the method will succeed by calling iam_credentials_available?.

About IAMCredentials

A service account is a special type of Google account that belongs to your application or a virtual machine (VM), instead of to an individual end user. Your application assumes the identity of the service account to call Google APIs, so that the users aren't directly involved.

Service account credentials are used to temporarily assume the identity of the service account. Supported credential types include OAuth 2.0 access tokens, OpenID Connect ID tokens, self-signed JSON Web Tokens (JWTs), and more.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/google/iam/credentials.rb', line 65

def self.iam_credentials version: :v1, transport: :grpc, &block
  require "google/iam/credentials/#{version.to_s.downcase}"

  package_name = Google::Iam::Credentials
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Iam::Credentials.const_get(package_name).const_get(:IAMCredentials)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.iam_credentials_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the IAMCredentials service is supported by the current client. If true, you can retrieve a client object by calling iam_credentials. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the IAMCredentials service, or if the versioned client gem needs an update to support the IAMCredentials service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/google/iam/credentials.rb', line 89

def self.iam_credentials_available? version: :v1, transport: :grpc
  require "google/iam/credentials/#{version.to_s.downcase}"
  package_name = Google::Iam::Credentials
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Iam::Credentials.const_get package_name
  return false unless service_module.const_defined? :IAMCredentials
  service_module = service_module.const_get :IAMCredentials
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end